' *****************************************************************************
' File    : PDFChart.vb
' Author  : Utility Warrior, (c) 2005-2007
' Project : PDF Chart Creator (PDFChart) Dynamic Link Library
' Purpose : This file provides VB.net prototypes for all DLL functions
'
' Please refer to the accompanying documentation for full details.
' *****************************************************************************

Imports System.Runtime.InteropServices

Public Class Win32
    ' *************************************************************************
    ' This allows the support of multiple versions of a DLL (if and when
    ' available) so that functions that might only be available in a later
    ' version can then only be called if the returned version currently being 
    ' used is one that supports those functions.
    '   
    ' Return value: integer value representing the DLL version
    ' a value of 100 is equivalent to version 1.00
    ' *************************************************************************
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_GetDLLVersion() As Integer
    End Function


    ' *************************************************************************
    ' Required
    ' *************************************************************************
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_License(ByVal code As String)
    End Sub
    ' This is required to remove the "Evaluation Mode" message that is stamped 
    ' over the top of every page in the output PDF document.   
    '
    ' To purchase a license code please visit the Utility Warrior web site which 
    ' has the latest information and prices on the licenses that are available. 
    '
    ' Return value: none 


    Public Const CHART_BAR_VERTICAL As Integer = 1
    Public Const CHART_BAR_HORIZONTAL As Integer = 2
    Public Const CHART_PIE_2D As Integer = 3
    Public Const CHART_LINE_STANDARD As Integer = 4
    Public Const CHART_LINE_STEPPED As Integer = 5
    Public Const CHART_LINE_CURVED As Integer = 6
    Public Const CHART_AREA_STANDARD As Integer = 7
    Public Const CHART_AREA_STEPPED As Integer = 8
    Public Const CHART_AREA_CURVED As Integer = 9
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_Chart(ByVal type As Integer) As Integer
    End Function
    ' Specify which chart type is to be generated.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid chart type


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_Page(ByVal width As Integer, ByVal height As Integer, ByVal red As Double, ByVal green As Double, ByVal blue As Double) As Integer
    End Function
    ' Specify page size and background color
    '
    ' Width and height must be between 100 and 10000 inclusive
    '
    ' Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
    '
    ' Return value:
    ' 0 - success
    ' 1 - width invalid
    ' 2 - height invalid
    ' 3 - red invalid
    ' 4 - green invalid
    ' 5 - blue invalid


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_PageName(ByVal name As String, ByVal landscape As Integer, ByVal red As Double, ByVal green As Double, ByVal blue As Double) As Integer
    End Function
    ' Specify page size using common name and background color
    '
    ' name must be one of: A0, A1, A2, A3, A4, A5, B0, B1, B2, B3, B4, B5, Letter, Tabloid, Ledger, Executive, Legal, Folio, Foolscap, Quarto, Statement
    '
    ' landscape value of 1 rotates the page size, 0 leaves it in portrait orientations
    '
    ' Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
    '
    ' Return value:
    ' 0 - success
    ' 1 - name invalid
    ' 2 - red invalid
    ' 3 - green invalid
    ' 4 - blue invalid


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_DataSet(ByVal filename As String) As Integer
    End Function
    ' Load in chart data from an external file - either this and/or an appropriate chart
    ' type datum function must be used in order to define at least one item of data
    '
    ' Up to 1000 data items can be added.
    '
    ' Return value:
    ' 0 - success
    ' 1 - no chart type specified
    ' 2 - could not open filename
    ' 3 - maximum number of data items reached
    ' 101...
    '	  - line (101 - 100), ie line 1 contains invalid data


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_DataSeparator(ByVal separator As String) As Integer
    End Function
    ' Set the data separator text that is used to delineate data fields when loading in data 
    ' from an external file, by default this is a comma
    '
    ' A maximum of 10 characters can be used.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter


    Public Const SORT_ASCENDING As Integer = 1
    Public Const SORT_DESCENDING As Integer = 2
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_DataSort(ByVal field As Integer, ByVal order As Integer) As Integer
    End Function
    ' Specify that the data items are to be sorted before being displayed within the chart
    '
    ' field must be either 1 or 2
    '
    ' 0 - success
    ' 1 - field invalid
    ' 2 - order invalid


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_Log(ByVal logFilename As String) As Integer
    End Function
    ' Information and error messages are appended to the end of the file specified (with a timestamp).
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid logFilename


    ' *************************************************************************
    ' Area Chart Specific
    ' *************************************************************************
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_AreaDatum(ByVal label As String, ByVal value As Double) As Integer
    End Function
    ' Add an item of area data.
    '
    ' Up to 1000 data items can be added.
    '
    ' Return value:
    ' 0 - success
    ' 1 - area chart type not specified
    ' 2 - maximum number of data items already reached
    ' 3 - label invalid


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_Area(ByVal lineRed As Double, ByVal lineGreen As Double, ByVal lineBlue As Double, ByVal lineThickness As Double, ByVal fillRed As Double, ByVal fillGreen As Double, ByVal fillBlue As Double) As Integer
    End Function
    ' Specifies how the area under the data points is to be filled.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid lineRed
    ' 2 - invalid lineGreen
    ' 3 - invalid lineBlue
    ' 4 - invalid lineThickness
    ' 5 - invalid fillRed
    ' 6 - invalid fillGreen
    ' 7 - invalid fillBlue


    ' *************************************************************************
    ' Line Chart Specific
    ' *************************************************************************
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_LineDatum(ByVal label As String, ByVal value As Double) As Integer
    End Function
    ' Add an item of line data.
    '
    ' Up to 1000 data items can be added.
    '
    ' Return value:
    ' 0 - success
    ' 1 - line chart type not specified
    ' 2 - maximum number of data items already reached
    ' 3 - label invalid


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_Line(ByVal lineRed As Double, ByVal lineGreen As Double, ByVal lineBlue As Double, ByVal lineThickness As Double) As Integer
    End Function
    ' Specifies the line color and thickness that connects all of the data points together.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid lineRed
    ' 2 - invalid lineGreen
    ' 3 - invalid lineBlue
    ' 4 - invalid lineThickness


	Public Const LINE_POINT_STYLE_FILLED_CIRCLE		As Integer = 1
	Public Const LINE_POINT_STYLE_OUTLINE_CIRCLE	As Integer = 2
	Public Const LINE_POINT_STYLE_FILLED_SQUARE		As Integer = 3
	Public Const LINE_POINT_STYLE_OUTLINE_SQUARE	As Integer = 4
	Public Const LINE_POINT_STYLE_CROSS				As Integer = 5
	Public Const LINE_POINT_STYLE_FILLED_DIAMOND	As Integer = 6
	Public Const LINE_POINT_STYLE_OUTLINE_DIAMOND	As Integer = 7
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_LineMarker(ByVal markerRed As Double, ByVal markerGreen As Double, ByVal markerBlue As Double, ByVal size As Double, ByVal markerStyle As Integer, ByVal outlineThickness As Double) As Integer
    End Function
	' Specifies a marker to be displayed on the line at the data point position.
	'
	' Return value:
	' 0 - success
	' 1 - invalid markerRed
	' 2 - invalid markerGreen
	' 3 - invalid markerBlue
	' 4 - invalid size
	' 5 - invalid markerStyle
	' 6 - invalid outlineThickness


    ' *************************************************************************
    ' Bar Chart Specific
    ' *************************************************************************
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_BarDatum(ByVal label As String, ByVal value As Double) As Integer
    End Function
    ' Add an item of bar data.
    '
    ' Up to 1000 data items can be added.
    '
    ' Return value:
    ' 0 - success
    ' 1 - bar chart type not specified
    ' 2 - maximum number of data items already reached
    ' 3 - label invalid


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_BarColor(ByVal fromRed As Double, ByVal fromGreen As Double, ByVal fromBlue As Double, ByVal toRed As Double, ByVal toGreen As Double, ByVal toBlue As Double) As Integer
    End Function
    ' Sets a color (range) for a bar
    '
    ' Up to 50 bar colors can be defined
    '
    ' Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
    '
    ' Return value:
    ' 0 - success
    ' 1 - maximum number of bar colors already specified
    ' 2 - from red invalid
    ' 3 - from green invalid
    ' 4 - from blue invalid
    ' 5 - to red invalid
    ' 6 - to green invalid
    ' 7 - to blue invalid


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_BarSpacing(ByVal spacing As Integer) As Integer
    End Function
    ' Sets the amount of spacing between bars (bar size automatically calculated from this)
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid spacing, must be between 0 and 500 inclusive


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_BarSize(ByVal size As Integer) As Integer
    End Function
    ' Sets the bar size (bar spacing automatically calculated from this)
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid size, must be between 1 and 500 inclusive


    Public Const LABEL_AT_START As Integer = 1
    Public Const LABEL_AT_END As Integer = 2
    Public Const LABEL_AT_CENTER As Integer = 3
    Public Const LABEL_AT_AXES As Integer = 4
    Public Const LABEL_AT_AXES_AND_START As Integer = 5
    Public Const LABEL_AT_AXES_AND_END As Integer = 6
    Public Const LABEL_AT_AXES_AND_CENTER As Integer = 7
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_BarLabel(ByVal labelPosition As Integer, ByVal format As String) As Integer
    End Function
    ' Set the position and label style
    '
    ' Return value:
    ' 0 - success
    ' 1 - label position not valid
    ' 2 - invalid format


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_BarBorder(ByVal width As Double, ByVal red As Double, ByVal green As Double, ByVal blue As Double) As Integer
    End Function
    ' Set the bar border width and color
    '
    ' width must be > 0.0 and <= 100.0
    '
    ' Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
    '
    ' 0 - success
    ' 1 - width invalid
    ' 2 - red invalid
    ' 3 - green invalid
    ' 4 - blue invalid


    ' *************************************************************************
    ' Axes and Labels
    ' *************************************************************************
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_ChartBackground(ByVal fromRed As Double, ByVal fromGreen As Double, ByVal fromBlue As Double, ByVal toRed As Double, ByVal toGreen As Double, ByVal toBlue As Double) As Integer
    End Function
    ' Sets the background color (range) for the chart
    '
    ' Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
    '
    ' Return value:
    ' 0 - success
    ' 1 - from red invalid
    ' 2 - from green invalid
    ' 3 - from blue invalid
    ' 4 - to red invalid
    ' 5 - to green invalid
    ' 6 - to blue invalid


    Public Const VERTICAL_ALIGNMENT_TOP As Integer = 1
    Public Const VERTICAL_ALIGNMENT_MIDDLE As Integer = 2
    Public Const VERTICAL_ALIGNMENT_BOTTOM As Integer = 3

    Public Const HORIZONTAL_ALIGNMENT_LEFT As Integer = 1
    Public Const HORIZONTAL_ALIGNMENT_CENTER As Integer = 2
    Public Const HORIZONTAL_ALIGNMENT_RIGHT As Integer = 3
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_ChartHeading(ByVal verticalAlignment As Integer, ByVal horizontalAlignment As Integer) As Integer
    End Function
    ' Sets the chart heading position
    '
    ' vertical alignment must be either top or bottom (NOT middle)
    '
    ' Return value:
    ' 0 - success
    ' 1 - vertical alignment invalid
    ' 2 - horizontal alignment invalid


    Public Const FONT_ID_COURIER As Integer = 1
    Public Const FONT_ID_COURIER_BOLD As Integer = 2
    Public Const FONT_ID_COURIER_BOLDOBLIQUE As Integer = 3
    Public Const FONT_ID_COURIER_OBLIQUE As Integer = 4
    Public Const FONT_ID_HELVETICA As Integer = 5
    Public Const FONT_ID_HELVETICA_BOLD As Integer = 6
    Public Const FONT_ID_HELVETICA_BOLDOBLIQUE As Integer = 7
    Public Const FONT_ID_HELVETICA_OBLIQUE As Integer = 8
    Public Const FONT_ID_TIMES_ROMAN As Integer = 9
    Public Const FONT_ID_TIMES_BOLD As Integer = 10
    Public Const FONT_ID_TIMES_ITALIC As Integer = 11
    Public Const FONT_ID_TIMES_BOLDITALIC As Integer = 12
    Public Const FONT_ID_SYMBOL As Integer = 13
    Public Const FONT_ID_ZAPFDINGBATS As Integer = 14

    Public Const TEXT_STYLE_NORMAL As Integer = 1
    Public Const TEXT_STYLE_STROKE As Integer = 2
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_HeadingTitle(ByVal size As Integer, ByVal fontID As Integer, ByVal fillRed As Double, ByVal fillGreen As Double, ByVal fillBlue As Double, ByVal style As Integer, ByVal otherRed As Double, ByVal otherGreen As Double, ByVal otherBlue As Double) As Integer
    End Function
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_HeadingSubTitle(ByVal size As Integer, ByVal fontID As Integer, ByVal fillRed As Double, ByVal fillGreen As Double, ByVal fillBlue As Double, ByVal style As Integer, ByVal otherRed As Double, ByVal otherGreen As Double, ByVal otherBlue As Double) As Integer
    End Function
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_AxesLabelX(ByVal size As Integer, ByVal fontID As Integer, ByVal fillRed As Double, ByVal fillGreen As Double, ByVal fillBlue As Double, ByVal style As Integer, ByVal otherRed As Double, ByVal otherGreen As Double, ByVal otherBlue As Double) As Integer
    End Function
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_AxesLabelY(ByVal size As Integer, ByVal fontID As Integer, ByVal fillRed As Double, ByVal fillGreen As Double, ByVal fillBlue As Double, ByVal style As Integer, ByVal otherRed As Double, ByVal otherGreen As Double, ByVal otherBlue As Double) As Integer
    End Function
    ' Sets the appropriate text style
    '
    ' size must be between 1 and 300 inclusive
    '
    ' Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
    '
    ' other color is only required if the style is stroke
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid size
    ' 2 - invalid font 
    ' 3 - fill red invalid
    ' 4 - fill green invalid
    ' 5 - fill blue invalid
    ' 6 - invalid style
    ' 7 - other red invalid
    ' 8 - other green invalid
    ' 9 - other blue invalid


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_AxesCaptionX(ByVal size As Integer, ByVal fontID As Integer, ByVal fillRed As Double, ByVal fillGreen As Double, ByVal fillBlue As Double, ByVal style As Integer, ByVal otherRed As Double, ByVal otherGreen As Double, ByVal otherBlue As Double, ByVal horizontalAlignment As Integer, ByVal label As String) As Integer
    End Function
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_AxesCaptionY(ByVal size As Integer, ByVal fontID As Integer, ByVal fillRed As Double, ByVal fillGreen As Double, ByVal fillBlue As Double, ByVal style As Integer, ByVal otherRed As Double, ByVal otherGreen As Double, ByVal otherBlue As Double, ByVal verticalAlignment As Integer, ByVal label As String) As Integer
    End Function
    ' Sets the appropriate axes label style and text
    '
    ' size must be between 1 and 300 inclusive
    '
    ' Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
    '
    ' other color is only required if the style is stroke
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid size
    ' 2 - invalid font 
    ' 3 - fill red invalid
    ' 4 - fill green invalid
    ' 5 - fill blue invalid
    ' 6 - invalid style
    ' 7 - other red invalid
    ' 8 - other green invalid
    ' 9 - other blue invalid
    ' 10 - invalid horizontal/vertical alignment
    ' 11 - label is invalid


    Public Const AXES_LINE_XY As Integer = 1
    Public Const AXES_LINE_FULL As Integer = 2
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_AxesLine(ByVal width As Double, ByVal red As Double, ByVal green As Double, ByVal blue As Double, ByVal format As Integer) As Integer
    End Function
    ' Sets the width, color and style for the axes boundary lines surrounding the chart area
    '
    ' width must be between 0.1 and 100.0 inclusive
    '
    ' Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid width
    ' 2 - red invalid
    ' 3 - green invalid
    ' 4 - blue invalid
    ' 5 - invalid line format


    Public Const AXES_SCALE_FROM_ZERO As Integer = 1
    Public Const AXES_SCALE_UNDER_LOWEST_VALUE As Integer = 2
    Public Const AXES_SCALE_RANGE As Integer = 3
    Public Const AXES_SCALE_EITHER_SIDE As Integer = 4
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_AxesScale(ByVal scale As Integer, ByVal value1 As Double, ByVal value2 As Double) As Integer
    End Function
    ' Sets the width, color and style for the axes boundary lines surrounding the chart area
    '
    ' if scale is AXES_SCALE_FROM_ZERO then value1 and value2 are not used
    ' if scale is AXES_SCALE_UNDER_LOWEST_VALUE then value1 is an integer percentage from 0 to 100%, value2 is not used
    ' if scale is AXES_SCALE_RANGE then the axes range is from value1 to value2
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid scale type
    ' 2 - invalid percentage


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_AxesDivisions(ByVal divisions As Integer) As Integer
    End Function
    ' Sets the number of divisions in the axes scale
    '
    ' divisions must be between 1 and 100 inclusive
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid divisions


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_DecimalPoints(ByVal points As Integer) As Integer
    End Function
    ' Sets the number of decimal points to be displayed with a real number
    '
    ' points must be between 0 and 9 inclusive
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid points


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_AxesGridLineStyle(ByVal dash As Integer, ByVal gap As Integer, ByVal offset As Integer) As Integer
    End Function
    ' Sets the dashed line style for the grid lines
    '
    ' all parameters must be between 0 and 100 inclusive
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid dash
    ' 2 - invalid gap
    ' 3 - invalid offset


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_AxesGridLine(ByVal width As Double, ByVal red As Double, ByVal green As Double, ByVal blue As Double) As Integer
    End Function
    ' Sets the width and color of the axes grid lines that are drawn within the chart area
    '
    ' width must be between 0.1 and 100.0 inclusive
    '
    ' Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid width
    ' 2 - red invalid
    ' 3 - green invalid
    ' 4 - blue invalid


    Public Const AXES_LABEL_Y_POSITION_TO_LEFT As Integer = 1
    Public Const AXES_LABEL_Y_POSITION_TO_RIGHT As Integer = 2
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_AxesLabelYPosition(ByVal position As Integer) As Integer
    End Function
    ' Controls which side of the chart the Y axis label is displayed
    '
    ' position must be either AXES_LABEL_Y_POSITION_TO_LEFT or AXES_LABEL_Y_POSITION_TO_RIGHT
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid position


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_AxesLabelSpacing(ByVal nth As Integer) As Integer
    End Function
    ' Controls the display of the X axis data labels (if the chart type supports this)
    ' so that it displays every nth label on the axes which is useful if there are a 
    ' lot of labels to display which would otherwise overwrite each other
    '
    ' nth must be between 1 and 50 inclusive
    '
    ' Return value:
    ' 0 - success
    ' 1 - nth is invalid


    ' *************************************************************************
    ' Pie Chart Specific
    ' *************************************************************************
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_PieDatum(ByVal label As String, ByVal value As Double) As Integer
    End Function
    ' Add an item of pie data.
    '
    ' Up to 1000 data items can be added.
    '
    ' Return value:
    ' 0 - success
    ' 1 - pie chart type not specified
    ' 2 - maximum number of data items already reached
    ' 3 - label invalid


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_PieColor(ByVal red As Double, ByVal green As Double, ByVal blue As Double) As Integer
    End Function
    ' Sets a color for a pie segment
    '
    ' Up to 50 bar colors can be defined
    '
    ' Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
    ' 
    ' Return value:
    ' 0 - success
    ' 1 - maximum number of pie colors already specified
    ' 2 - red invalid
    ' 3 - green invalid
    ' 4 - blue invalid


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_PieOutline(ByVal borderWidth As Double, ByVal red As Double, ByVal green As Double, ByVal blue As Double) As Integer
    End Function
    ' Sets a color for a pie segment
    '
    ' borderWidth must be between 0.0 and 100.0 inclusive
    '
    ' Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
    '
    ' Return value:
    ' 0 - success
    ' 1 - border width invalid
    ' 2 - red invalid
    ' 3 - green invalid
    ' 4 - blue invalid


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_PiePageMargin(ByVal marginSize As Double) As Integer
    End Function
    ' Sets the minimum spacing between the edge of the page and the chart
    '
    ' margin size must be between 0.0 and 100.0 inclusive
    '
    ' Return value:
    ' 0 - success
    ' 1 - margin size invalid


    Public Const LABEL_INSIDE As Integer = 8
    Public Const LABEL_OUTSIDE As Integer = 9
    Public Const LABEL_SPOKE As Integer = 10
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_PieLabel(ByVal labelPosition As Integer, ByVal format As String, ByVal size As Integer, ByVal fontID As Integer, ByVal fillRed As Double, ByVal fillGreen As Double, ByVal fillBlue As Double, ByVal style As Integer, ByVal otherRed As Double, ByVal otherGreen As Double, ByVal otherBlue As Double) As Integer
    End Function
    ' Sets the label text style
    '
    ' size must be between 1 and 300 inclusive
    '
    ' Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
    '
    ' other color is only required if the style is stroke
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid size
    ' 2 - invalid font 
    ' 3 - fill red invalid
    ' 4 - fill green invalid
    ' 5 - fill blue invalid
    ' 6 - invalid style
    ' 7 - other red invalid
    ' 8 - other green invalid
    ' 9 - other blue invalid
    ' 10 - invalid label format
    ' 11 - invalid label position


    ' *************************************************************************
    ' Legends
    ' *************************************************************************
    Public Const LEGEND_NONE As Integer = 0
    Public Const LEGEND_ABOVE As Integer = 1
    Public Const LEGEND_BELOW As Integer = 2
    Public Const LEGEND_LEFT As Integer = 3
    Public Const LEGEND_RIGHT As Integer = 4
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_Legend(ByVal legendPosition As Integer, ByVal format As String, ByVal outlineRed As Double, ByVal outlineGreen As Double, ByVal outlineBlue As Double, ByVal outlineWidth As Double, ByVal backgroundRed As Double, ByVal backgroundGreen As Double, ByVal backgroundBlue As Double, ByVal size As Integer, ByVal fontID As Integer, ByVal fillRed As Double, ByVal fillGreen As Double, ByVal fillBlue As Double, ByVal style As Integer, ByVal otherRed As Double, ByVal otherGreen As Double, ByVal otherBlue As Double) As Integer
    End Function
    ' Legend box settings
    '
    ' size must be between 1 and 300 inclusive
    '
    ' Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
    '
    ' other color is only required if the style is stroke
    '
    ' Return value:
    ' 0 - success
    ' 1 - legend position invalid
    ' 2 - outline red invalid
    ' 3 - outline green invalid
    ' 4 - outline blue invalid
    ' 5 - invalid outline width
    ' 6 - background red invalid
    ' 7 - background green invalid
    ' 8 - background blue invalid
    ' 9 - invalid legend format
    ' 10 - invalid size
    ' 11 - invalid font 
    ' 12 - fill red invalid
    ' 13 - fill green invalid
    ' 14 - fill blue invalid
    ' 15 - invalid style
    ' 16 - other red invalid
    ' 17 - other green invalid
    ' 18 - other blue invalid


    ' *************************************************************************
    ' Numerical Analyses
    ' *************************************************************************
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_LineOfBestFit(ByVal lineRed As Double, ByVal lineGreen As Double, ByVal lineBlue As Double, ByVal lineThickness As Double) As Integer
    End Function
    ' Specifies the line thickness and color that is used to display the "line of best fit".
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid lineRed
    ' 2 - invalid lineGreen
    ' 3 - invalid lineBlue
    ' 4 - invalid lineThickness


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_MovingAverageLine(ByVal samplePoints As Integer, ByVal lineRed As Double, ByVal lineGreen As Double, ByVal lineBlue As Double, ByVal lineThickness As Double) As Integer
    End Function
    ' The moving average at any given point is the average of that point and the preceeding <samplePoints - 1> data items.
    ' This means that the first moving average point that can be plotted is not at the first position on the chart but at the <samplePoints> position.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid lineRed
    ' 2 - invalid lineGreen
    ' 3 - invalid lineBlue
    ' 4 - invalid lineThickness
    ' 5 - invalid samples


	' Following values already defined above
	' LINE_POINT_STYLE_FILLED_CIRCLE
	' LINE_POINT_STYLE_OUTLINE_CIRCLE
	' LINE_POINT_STYLE_FILLED_SQUARE
	' LINE_POINT_STYLE_OUTLINE_SQUARE
	' LINE_POINT_STYLE_CROSS
	' LINE_POINT_STYLE_FILLED_DIAMOND
	' LINE_POINT_STYLE_OUTLINE_DIAMOND
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_MovingAverageLineMarker(ByVal markerStyle As Integer, ByVal markerRed As Double, ByVal markerGreen As Double, ByVal markerBlue As Double, ByVal markerSize As Double, ByVal outlineThickness As Double) As Integer
    End Function
    ' This is optional and specifies a marker to be displayed on the moving average line at the data point position.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid markerStyle
    ' 2 - invalid markerRed
    ' 3 - invalid markerGreen
    ' 4 - invalid markerBlue
    ' 5 - invalid markerSize
    ' 6 - invalid outlineThickness


    ' *************************************************************************
    ' PDF Settings
    ' *************************************************************************
    Public Const PDF_PERMISSION_READ_ONLY As Integer = 0
    Public Const PDF_PERMISSION_EDIT As Integer = 1
    Public Const PDF_PERMISSION_EDIT_EXTRA As Integer = 2
    Public Const PDF_PERMISSION_COPY As Integer = 4
    Public Const PDF_PERMISSION_PRINT As Integer = 8
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_SetPermissions(ByVal iPermissions As Integer) As Integer
    End Function
    ' Allows the setting of any combination of permissions in one go
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid permissions

    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_SetPermissionEdit()
    End Sub
    ' Allows editing/changing of the PDF document but NOT adding or changing of text 
    ' notes and AcroForm fields.
    '
    ' Return value: none 


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_SetPermissionEditExtra()
    End Sub
    ' Allows the adding and changing of text notes and AcroForm fields within a PDF document.
    '
    ' Return value: none 


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_SetPermissionCopy()
    End Sub
    ' Allows the copying of text and graphics from the PDF document.
    '
    ' Return value: none 


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_SetPermissionPrint()
    End Sub
    ' Allows printing of the PDF document.
    '
    ' Return value: none 


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_SetOwnerPassword(ByVal password As String) As Integer
    End Function
    ' The owner of a PDF document would enter this password in order to view it
    ' and make changes and perform actions that may be restricted to a normal user.
    '
    ' A maximum of 32 characters can be used.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_SetUserPassword(ByVal password As String) As Integer
    End Function
    ' In order that only the intended user can view the PDF document, they must type
    ' in this password, otherwise the user is not allowed to read the PDF document.
    '
    ' A maximum of 32 characters can be used.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter


    ' *************************************************************************
    ' PDF Meta Information
    ' *************************************************************************
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_SetProducer(ByVal producer As String) As Integer
    End Function
    ' The name of the application that converted the document from its native format to PDF.
    '
    ' A maximum of 256 characters can be used.
    ' 
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_SetCreator(ByVal creator As String) As Integer
    End Function
    ' If the document was converted into a PDF document from another form, this is 
    ' usually the name of the application that created the original document.
    '
    ' A maximum of 256 characters can be used.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_SetAuthor(ByVal author As String) As Integer
    End Function
    ' The name of the person who created the PDF document.
    '
    ' A maximum of 256 characters can be used.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_SetTitle(ByVal title As String) As Integer
    End Function
    ' The PDF document's title.
    '
    ' A maximum of 256 characters can be used.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_SetSubject(ByVal subject As String) As Integer
    End Function
    ' The PDF document's subject.
    '
    ' A maximum of 256 characters can be used.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_SetKeywords(ByVal keywords As String) As Integer
    End Function
    ' A list of keywords associated with the PDF document.
    '
    ' A maximum of 256 characters can be used.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_SetCreationDate()
    End Sub
    ' The date that the PDF document was created.
    '
    ' This is set using the current local time of the PC.
    '
    ' Return value: none


    ' *************************************************************************
    ' PDF Viewer Preferences
    ' *************************************************************************
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_SetViewerPreferenceCenterWindow()
    End Sub
    ' The window displaying the PDF document should be displayed in the center of 
    ' the computer's screen.
    '
    ' Return value: none


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_SetViewerPreferenceHideToolbar()
    End Sub
    ' The PDF viewer's toolbar should be hidden when the PDF document is active.
    '
    ' Return value: none


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_SetViewerPreferenceHideMenubar()
    End Sub
    ' The PDF viewer's menubar should be hidden when the PDF document is active.
    '
    ' Return value: none


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_SetViewerPreferenceHideWindowUI()
    End Sub
    ' The user interface elements within the PDF document's window should be hidden.
    '
    ' Return value: none


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_SetViewerPreferenceFitWindow()
    End Sub
    ' The PDF viewer should resize the window displaying the PDF document to fit the 
    ' size of the first displayed page of the PDF document.
    '
    ' Return value: none


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_SetPageModeOutlines()
    End Sub
    ' The PDF viewer should show the outline (ie bookmark) navigation item when the 
    ' PDF document is open.
    '
    ' Return value: none


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_SetPageModeNone()
    End Sub
    ' The PDF viewer should not show the outline (ie bookmark) or thumbnail navigation
    ' items when the PDF document is open.
    '
    ' This is the default if no other page mode is specified.
    '
    ' Return value: none


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_SetPageModeUseThumbs()
    End Sub
    ' The PDF viewer should show the thumbnail navigation item when the PDF document 
    ' is open.
    '
    ' Return value: none


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_SetPageModeFullScreen()
    End Sub
    ' The PDF viewer should open the PDF document in full-screen mode without showing 
    ' the menu bar, window controls or any other window.
    '
    ' Return value: none


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_SetPageLayoutSinglePage()
    End Sub
    ' Display the pages one page at a time.
    '
    ' Return value: none


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_SetPageLayoutOneColumn()
    End Sub
    ' Display the pages in one column.
    '
    ' Return value: none


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_SetPageLayoutTwoColumnLeft()
    End Sub
    ' Display the pages in two columns, with odd-numbered pages on the left.
    '
    ' Return value: none


    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub PDFC_SetPageLayoutTwoColumnRight()
    End Sub
    ' Display the pages in two columns, with odd-numbered pages on the right.
    '
    ' Return value: none


    ' *************************************************************************
    ' Specifies the name and location of the produced PDF document, 
    ' *************************************************************************
    Public Const OPTION_NONE As Integer = 0
    Public Const OPTION_OPEN_PDF As Integer = 1
    Public Const OPTION_RESET As Integer = 2
    <DllImport("PDFChart.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function PDFC_MakePDF(ByVal output As String, ByVal options As Integer, ByRef errorText As String, ByVal maxErrorTextSize As Integer) As Integer
    End Function
    ' Generate the output PDF according to the settings already selected through
    ' the Application Programming Interface functions above.
    '
    ' To have the output PDF open in the default PDF viewer set the OPTION_OPEN_PDF
    ' bit flag in the options parameter.
    '
    ' To have all settings applied reset after PDF has been generated set the OPTION_RESET
    ' bit flag in the options parameter.
    '
    ' Return value:
    ' 0 - success
    ' 1 - internal error - see errorText for details (unless NULL passed)
    ' 2 - output pdf could not be opened
    ' 3 - chart type not specified
    ' 4 - chart style not specified
    ' 5 - no data items to chart
    ' 6 - no output pdf filename specified
    ' 7 - no bar colors specified
    ' 8 - no pie colors specified
End Class
